from django.conf.urls.defaults import patterns, include, url
from django.views.generic.simple import direct_to_template
from django.views.generic.simple import redirect_to

from django.contrib.auth.views import login, logout
from views import *

urlpatterns = patterns("",
# url(r'^accounts/profile/', redirect_to, {"url": "/"}),

url(r"^$",
    home_view,
    name="simpleblog", ),

url(r'^t/(?P<url_key>[a-zA-Z0-9-/]+)/$',
     tag_view,
     name="simpleblog.tag", ),

url(r'^a/(?P<url_key>[a-zA-Z0-9-/]+)/$',
     article_view,
     name="simpleblog.article", ),

url(r'^js/lightbox.js$',
     direct_to_template,
     {"template": "simpleblog/lightbox/lightbox.js", "mimetype": "text/javascript"},
     name="simpleblog.js.lightbox", ),

# url(r"^knihy/$",
#     book_list_view,
#     name="prodejknihu.book_list", ),

# url(r'^kniha/(?P<book_pk>\d+)/(?P<seo>[a-zA-Z0-9-/]+)/$',
#      book_detail_view,
#      name="prodejknihu.book_detail", ),
)